@@ -45,6 +45,10 @@
 #include <ctype.h>
 #include <fcntl.h>
 
+#if defined(__sun)
+# include <limits.h>
+#endif
+
 #ifdef sgi
 # include <sys/sysmacros.h>
 #endif
@@ -109,7 +113,7 @@
 # include <shadow.h>
 #endif /* SHADOWPW */
 
-#include "logfile.h"	/* islogfile, logfflush */
+#include "logfile.h" /* islogfile, logfflush, logfopen/logfclose */
 
 #ifdef DEBUG
 FILE *dfp;
@@ -302,7 +306,7 @@ struct passwd *ppp;
 pw_try_again:
 #endif
   n = 0;
-  if (ppp->pw_passwd[0] == '#' && ppp->pw_passwd[1] == '#' & strcmp(ppp->pw_passwd + 2, ppp->pw_name) == 0)
+  if (ppp->pw_passwd[0] == '#' && ppp->pw_passwd[1] == '#' && strcmp(ppp->pw_passwd + 2, ppp->pw_name) == 0)
     n = 13;
   for (; n < 13; n++) {
     char c = ppp->pw_passwd[n];
@@ -497,6 +501,11 @@ int main(int ac, char** av)
   af = AF_UNSPEC;
 #endif
 
+  real_uid = getuid();
+  real_gid = getgid();
+  eff_uid = geteuid();
+  eff_gid = getegid();
+
   logreopen_register(lf_secreopen);
 
   av0 = *av;   /* if this is a login screen, assume -RR */
@@ -667,20 +676,20 @@ int main(int ac, char** av)
             break;
 
           case 'L':
-            if (--ac != 0) {
-              screenlogfile = SaveStr(*++av);
-              if (screenlogfile[0] == '-')
-                Panic(0, "-L: logfile name can not start with \"-\" symbol");
-              if (strlen(screenlogfile) > PATH_MAX)
-                Panic(0, "-L: logfile name too long. (max. %d char)", PATH_MAX);
+	    if (!strcmp(ap + 1, "ogfile")) {
+              if (--ac == 0)
+                exit_with_usage(myname, "Specify logfile path with -Logfile", NULL);
+
+              if (strlen(*++av) > PATH_MAX)
+                Panic(1, "-Logfile name too long. (max. %d char)", PATH_MAX);
+
+              free(screenlogfile); /* we already set it up while starting */
+              screenlogfile = SaveStr(*av);
+
+              ap = NULL;
+            } else if (!strcmp(ap, "L"))
+              nwin_options.Lflag = 1;
 
-              FILE *w_check;
-              if ((w_check = fopen(screenlogfile, "w")) == NULL)
-                Panic(0, "-L: logfile name access problem");
-              else
-                fclose(w_check);
-            }
-            nwin_options.Lflag = 1;
             break;
 
           case 'm':
@@ -789,10 +798,6 @@ int main(int ac, char** av)
     else
       break;
   }
-  real_uid = getuid();
-  real_gid = getgid();
-  eff_uid = geteuid();
-  eff_gid = getegid();
 
 #ifdef SIGBUS /* OOPS, linux has no bus errors! */
   signal(SIGBUS, CoreDump);
