@@ -36,7 +36,6 @@ extern int real_uid, real_gid, eff_uid, eff_gid;
 extern struct term term[];	/* terminal capabilities */
 extern struct NewWindow nwin_undef, nwin_default, nwin_options;
 extern int force_vt;
-extern int Z0width, Z1width;
 extern int hardstatusemu;
 #ifdef MAPKEYS
 extern struct action umtab[];
@@ -72,7 +71,7 @@ char Termcap[TERMCAP_BUFSIZE + 8];	/* new termcap +8:"TERMCAP=" */
 static int Termcaplen;
 static int tcLineLen;
 char Term[MAXSTR+5];		/* +5: "TERM=" */
-char screenterm[20];		/* new $TERM, usually "screen" */
+char screenterm[MAXTERMLEN + 1];	/* new $TERM, usually "screen" */
 
 char *extra_incap, *extra_outcap;
 
@@ -389,11 +388,11 @@ int he;
     {
       /* init with default string first */
       s = "l+m+k+j+u+t+v+w+q-x|n+o~s_p\"r#`+a:f'g#~o.v-^+<,>h#I#0#y<z>";
-      for (i = strlen(s) & ~1; i >= 0; i -= 2)
+      for (i = (strlen(s) - 2) & ~1; i >= 0; i -= 2)
 	D_c0_tab[(int)(unsigned char)s[i]] = s[i + 1];
     }
   if (D_CC0)
-    for (i = strlen(D_CC0) & ~1; i >= 0; i -= 2)
+    for (i = (strlen(D_CC0) - 2) & ~1; i >= 0; i -= 2)
       D_c0_tab[(int)(unsigned char)D_CC0[i]] = D_CC0[i + 1];
   debug1("ISO2022 = %d\n", D_CG0);
 #endif /* FONT */
@@ -410,8 +409,6 @@ int he;
   /* Termcap fields Z0 & Z1 contain width-changing sequences. */
   if (D_CZ1 == 0)
     D_CZ0 = 0;
-  Z0width = 132;
-  Z1width = 80;
 
   CheckScreenSize(0);
 
@@ -883,7 +880,8 @@ int aflag;
   if (*screenterm == '\0' || strlen(screenterm) > MAXSTR - 3)
     {
       debug("MakeTermcap sets screenterm=screen\n");
-      strcpy(screenterm, "screen");
+      strncpy(screenterm, "screen", MAXTERMLEN);
+      screenterm[MAXTERMLEN] = '\0';
     }
 #if 0
   found = 1;
